==> MetaModel-core-4.5.4-sources.jar: org/apache/metamodel/data/EmptyDataSet.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.metamodel.data;

import java.util.List;

import org.apache.metamodel.query.SelectItem;
import org.apache.metamodel.schema.Column;

/**
 * An empty data set.
 */
public final class EmptyDataSet extends AbstractDataSet {
    
    public EmptyDataSet(DataSetHeader header) {
        super(header);
    }

    public EmptyDataSet(SelectItem[] selectItems) {
        super(new SimpleDataSetHeader(selectItems));
    }

    public EmptyDataSet(Column[] columns) {
        super(new SimpleDataSetHeader(columns));
    }

    public EmptyDataSet(List<SelectItem> selectItems) {
       this(new SimpleDataSetHeader(selectItems));
    }

    @Override
    public boolean next() {
        return false;
    }

    @Override
    public Row getRow() {
        return null;
    }

}

==> MetaModel-core-5.3.2-sources.jar: org/apache/metamodel/data/EmptyDataSet.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.metamodel.data;

import java.util.List;
import java.util.stream.Collectors;

import org.apache.metamodel.query.SelectItem;
import org.apache.metamodel.schema.Column;

/**
 * An empty data set.
 */
public final class EmptyDataSet extends AbstractDataSet {
    
    public EmptyDataSet(DataSetHeader header) {
        super(header);
    }

    public EmptyDataSet(List<SelectItem> selectItems) {
       this(new SimpleDataSetHeader(selectItems));
    }

    public static EmptyDataSet fromColumns(List<Column> cols){
        return new EmptyDataSet(cols.stream().map(SelectItem::new).collect(Collectors.toList()));
    }

    @Override
    public boolean next() {
        return false;
    }

    @Override
    public Row getRow() {
        return null;
    }

}
